@@ -2,6 +2,8 @@
 
 import sys
 
+import afl
+
 def main():
     s = sys.stdin.read()
     if len(s) < 1:
@@ -14,8 +16,7 @@ def main():
         print('A non-zero value? How quaint!')
 
 if __name__ == '__main__':
-    import afl
-    afl.start()
+    afl.init()
     main()
 
 # vim:ts=4 sts=4 sw=4 et
