@@ -34,44 +34,50 @@ from .tools import (
 here = os.path.dirname(__file__)
 target = here + '/target.py'
 
-def run(cmd, stdin='', expected_exit_status=0):
+def run(cmd, stdin='', env=None, xstatus=0):
     child = ipc.Popen(
         list(cmd),
         stdin=ipc.PIPE,
         stdout=ipc.PIPE,
-        stderr=ipc.PIPE
+        stderr=ipc.PIPE,
+        env=(dict(os.environ, **env) if env else None),
     )
     (stdout, stderr) = child.communicate(stdin)
-    if child.returncode != expected_exit_status:
+    if child.returncode != xstatus:
         if str != bytes:
             stderr = stderr.decode('ASCII', 'replace')
         print(stderr)
         raise ipc.CalledProcessError(child.returncode, cmd[0])
     return (stdout, stderr)
 
-def run_afl_showmap(stdin, expected_stdout=None, expected_exit_status=0):
+def run_afl_showmap(stdin, env=None, xstdout=None, xstatus=0):
     tmpdir = tempfile.mkdtemp(prefix='python-afl.')
     outpath = tmpdir + '/out'
     try:
         (stdout, stderr) = run(
             ['afl-showmap', '-o', outpath, sys.executable, target],
             stdin=stdin,
-            expected_exit_status=expected_exit_status,
+            env=env,
+            xstatus=xstatus,
         )
-        if expected_stdout is not None:
-            assert_equal(stdout, expected_stdout)
+        del stderr  # make pylint happy
+        if xstdout is not None:
+            assert_equal(stdout, xstdout)
         with open(outpath, 'r') as file:
             return file.read()
     finally:
         shutil.rmtree(tmpdir)
 
 def test_diff():
-    out1 = run_afl_showmap(b'0', b'Looks like a zero to me!\n')
-    out2 = run_afl_showmap(b'1', b'A non-zero value? How quaint!\n')
+    out1 = run_afl_showmap(b'0', xstdout=b'Looks like a zero to me!\n')
+    out2 = run_afl_showmap(b'1', xstdout=b'A non-zero value? How quaint!\n')
     assert_not_equal(out1, out2)
 
 def test_exception():
-    out = run_afl_showmap(b'\xff', expected_exit_status=2)
+    out = run_afl_showmap(b'\xff',
+        env=dict(PYTHON_AFL_SIGNAL='SIGUSR1'),
+        xstatus=2,
+    )
     assert_not_equal(out, b'')
 
 # vim:ts=4 sts=4 sw=4 et
